@@ -29,14 +29,6 @@ from gpodder import util
 
 from gpodder.gtkui.base import GtkBuilderWidget
 
-from gpodder.gtkui.widgets import NotificationWindow
-
-try:
-    import pynotify
-    if not pynotify.init('gPodder'):
-        pynotify = None
-except ImportError:
-    pynotify = None
 
 class BuilderWidget(GtkBuilderWidget):
     def __init__(self, parent, **kwargs):
@@ -65,34 +57,6 @@ class BuilderWidget(GtkBuilderWidget):
                 (pw, ph) = self.main_window.get_size()
                 self.main_window.move(x + w/2 - pw/2, y + h/2 - ph/2)
 
-    def _on_key_press_event_maemo(self, widget, event):
-        window_type = widget.get_type_hint()
-        if window_type != gtk.gdk.WINDOW_TYPE_HINT_NORMAL:
-            return False
-
-        if event.keyval == gtk.keysyms.F6:
-            if self._maemo_fullscreen:
-                if self._maemo_fullscreen_chain is not None:
-                    self._maemo_fullscreen_chain.unfullscreen()
-                self.main_window.unfullscreen()
-                self.main_window.set_border_width(0)
-            else:
-                if self._maemo_fullscreen_chain is not None:
-                    self._maemo_fullscreen_chain.fullscreen()
-                self.main_window.fullscreen()
-                self.main_window.set_border_width(12)
-            return True
-        else:
-            return False
-
-    def _on_window_state_event_maemo(self, widget, event):
-        if event.new_window_state & gtk.gdk.WINDOW_STATE_FULLSCREEN:
-            self._maemo_fullscreen = True
-        else:
-            self._maemo_fullscreen = False
-
-        return False
-
     def _on_window_state_event_visibility(self, widget, event):
         if event.state & gtk.gdk.VISIBILITY_FULLY_OBSCURED:
             self._window_visible = False
@@ -124,9 +88,6 @@ class BuilderWidget(GtkBuilderWidget):
         return self.main_window
 
     def show_message(self, message, title=None, important=False, widget=None):
-        # XXX: Dirty hack to get access to the gPodder-specific config object
-        config = getattr(self, '_config', getattr(self, 'config', None))
-
         if important:
             dlg = gtk.MessageDialog(self.main_window, gtk.DIALOG_MODAL, gtk.MESSAGE_INFO, gtk.BUTTONS_OK)
             if title:
@@ -136,24 +97,8 @@ class BuilderWidget(GtkBuilderWidget):
                 dlg.set_markup('<span weight="bold" size="larger">%s</span>' % (message))
             dlg.run()
             dlg.destroy()
-        elif config is not None and config.enable_notifications:
-            if pynotify is not None:
-                if title is None:
-                    title = 'gPodder'
-                notification = pynotify.Notification(title, message,\
-                        gpodder.icon_file)
-                try:
-                    notification.show()
-                except:
-                    # See http://gpodder.org/bug/966
-                    pass
-            elif widget and isinstance(widget, gtk.Widget):
-                if not widget.window:
-                    widget = self.main_window
-                elif not gpodder.win32:
-                    widget = self.main_window
-                notification = NotificationWindow(message, title, important=False, widget=widget)
-                notification.show_timeout()
+        else:
+            gpodder.user_extensions.on_notification_show(title, message)
 
     def show_confirmation(self, message, title=None):
         dlg = gtk.MessageDialog(self.main_window, gtk.DIALOG_MODAL, gtk.MESSAGE_QUESTION, gtk.BUTTONS_YES_NO)
@@ -209,9 +154,13 @@ class BuilderWidget(GtkBuilderWidget):
         else:
             return None
 
-    def show_login_dialog(self, title, message, username=None, password=None, username_prompt=_('Username'), register_callback=None):
-        """ An authentication dialog based on
-                http://ardoris.wordpress.com/2008/07/05/pygtk-text-entry-dialog/ """
+    def show_login_dialog(self, title, message, username=None, password=None,
+            username_prompt=None, register_callback=None, register_text=None):
+        if username_prompt is None:
+            username_prompt = _('Username')
+
+        if register_text is None:
+            register_text = _('New user')
 
         dialog = gtk.MessageDialog(
             self.main_window,
@@ -226,7 +175,7 @@ class BuilderWidget(GtkBuilderWidget):
         dialog.set_default_response(gtk.RESPONSE_OK)
 
         if register_callback is not None:
-            dialog.add_button(_('New user'), gtk.RESPONSE_HELP)
+            dialog.add_button(register_text, gtk.RESPONSE_HELP)
 
         username_entry = gtk.Entry()
         password_entry = gtk.Entry()
